#!/usr/bin/env node
"use strict";

exports.__esModule = true;
exports.opts = undefined;

var _fs = require("fs");

var _fs2 = _interopRequireDefault(_fs);

var _commander = require("commander");

var _commander2 = _interopRequireDefault(_commander);

var _kebabCase = require("lodash/kebabCase");

var _kebabCase2 = _interopRequireDefault(_kebabCase);

var _babelCore = require("babel-core");

var _uniq = require("lodash/uniq");

var _uniq2 = _interopRequireDefault(_uniq);

var _glob = require("glob");

var _glob2 = _interopRequireDefault(_glob);

var _dir = require("./dir");

var _dir2 = _interopRequireDefault(_dir);

var _file = require("./file");

var _file2 = _interopRequireDefault(_file);

var _package = require("../../package.json");

var _package2 = _interopRequireDefault(_package);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

Object.keys(_babelCore.options).forEach(function (key) {
  var option = _babelCore.options[key];
  if (option.hidden) return;

  var arg = (0, _kebabCase2.default)(key);

  if (option.type !== "boolean") {
    arg += " [" + (option.type || "string") + "]";
  }

  if (option.type === "boolean" && option.default === true) {
    arg = "no-" + arg;
  }

  arg = "--" + arg;

  if (option.shorthand) {
    arg = "-" + option.shorthand + ", " + arg;
  }

  var desc = [];
  if (option.deprecated) desc.push("[DEPRECATED] " + option.deprecated);
  if (option.description) desc.push(option.description);

  _commander2.default.option(arg, desc.join(" "));
});

_commander2.default.option("-x, --extensions [extensions]", "List of extensions to compile when a directory has been input [.es6,.js,.es,.jsx]");
_commander2.default.option("-w, --watch", "Recompile files on changes");
_commander2.default.option("--skip-initial-build", "Do not compile files before watching");
_commander2.default.option("-o, --out-file [out]", "Compile all input files into a single file");
_commander2.default.option("-d, --out-dir [out]", "Compile an input directory of modules into an output directory");
_commander2.default.option("-D, --copy-files", "When compiling a directory copy over non-compilable files");
_commander2.default.option("-q, --quiet", "Don't log anything");


_commander2.default.version(_package2.default.version + " (babel-core " + _babelCore.version + ")");
_commander2.default.usage("[options] <files ...>");
_commander2.default.parse(process.argv);

if (_commander2.default.extensions) {
  _commander2.default.extensions = _babelCore.util.arrayify(_commander2.default.extensions);
}

var errors = [];

var filenames = _commander2.default.args.reduce(function (globbed, input) {
  var files = _glob2.default.sync(input);
  if (!files.length) files = [input];
  return globbed.concat(files);
}, []);

filenames = (0, _uniq2.default)(filenames);

filenames.forEach(function (filename) {
  if (!_fs2.default.existsSync(filename)) {
    errors.push(filename + " doesn't exist");
  }
});

if (_commander2.default.outDir && !filenames.length) {
  errors.push("filenames required for --out-dir");
}

if (_commander2.default.outFile && _commander2.default.outDir) {
  errors.push("cannot have --out-file and --out-dir");
}

if (_commander2.default.watch) {
  if (!_commander2.default.outFile && !_commander2.default.outDir) {
    errors.push("--watch requires --out-file or --out-dir");
  }

  if (!filenames.length) {
    errors.push("--watch requires filenames");
  }
}

if (_commander2.default.skipInitialBuild && !_commander2.default.watch) {
  errors.push("--skip-initial-build requires --watch");
}

if (errors.length) {
  console.error(errors.join(". "));
  process.exit(2);
}

var opts = exports.opts = {};

Object.keys(_babelCore.options).forEach(function (key) {
  var opt = _babelCore.options[key];
  if (_commander2.default[key] !== undefined && _commander2.default[key] !== opt.default) {
    opts[key] = _commander2.default[key];
  }
});

opts.ignore = _babelCore.util.arrayify(opts.ignore, _babelCore.util.regexify);

if (opts.only) {
  opts.only = _babelCore.util.arrayify(opts.only, _babelCore.util.regexify);
}

var fn = _commander2.default.outDir ? _dir2.default : _file2.default;
fn(_commander2.default, filenames, opts);